#include "qmoviedb.h"
#include "QNetworkReply"
#include "QDebug"
#include "QJsonDocument"
#include "QJsonObject"
#include "QJsonArray"

QMovieDB::QMovieDB(QString apiKey, QObject *parent)
    : QObject{parent}, netMan(new QNetworkAccessManager(this)) {
    movieDbApiKey = apiKey;
    QObject::connect(netMan, &QNetworkAccessManager::finished, this, &QMovieDB::receiveReply);
}

void QMovieDB::searchMovieTitle(const QString title)
{
    QNetworkRequest req;
    req.setRawHeader("Accept", "application/json");

    QString bearer = "Bearer " + movieDbApiKey;
    req.setRawHeader("Authorization", bearer.toUtf8());

    QByteArray URL = QUrl::toPercentEncoding(title);
    URL = "https://api.themoviedb.org/3/search/movie?query=" + URL + "&include_adult=false&language=en-US&page=1";

    req.setUrl(QUrl(URL));
    netMan->get(req);
}

void QMovieDB::receiveReply(QNetworkReply *reply) {
    int responseStatus = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();

    if (responseStatus == 200) {
        parseResults(QJsonDocument::fromJson(reply->readAll()).object());
    } else {
        qInfo() << "Invalid Response. Status: " << responseStatus;
    }
}

void QMovieDB::parseResults(QJsonObject json) {
    qInfo() << "Total Results: " << json.value("total_results").toInt();

    QJsonValue results = json.value("results");
    QString releaseYear;
    QString titleYear;

    if (results.isArray()) {
        releaseYear = results.toArray().first().toObject().value("release_date").toString();
        releaseYear = "(" + releaseYear.left(releaseYear.indexOf("-")) + ")";
        titleYear = results.toArray().first().toObject().value("title").toString() + " " + releaseYear;
    } else {
        //If single result
    }

    qInfo() << titleYear;
}
